@@ -1,5 +1,7 @@
+# VERSION 0.09
 from .folder_tools import FolderTools
 from .img_tools import ImgTools
 from .video_tools import VideoTools
-from .utils import flush_print
+from .utils import MyTimer
+from .cv_ops import CVImage, CVQueue
 from .get_templates import GetTemplate
